@@ -28,7 +28,6 @@ import threading
 import platform
 import click
 
-os.chdir(__file__)
 
 
 
@@ -42,7 +41,8 @@ except:
 # Global Var
 verify_registered_email = list()
 ALLOWED_EXTENSIONS = {'txt', 'pdf', 'png', 'jpg', 'jpeg', 'gif'}
-Release = 'v0.1.0 Release'
+Release = 'v0.1.2.4 Release'
+
 
 # Get Configs File
 serverconf = dict(eval(open('server.conf', 'rb').read()))
@@ -144,6 +144,7 @@ class Tags(db.Model):
     icon = db.Column(db.String(30), server_defalt='message')
 
 
+
 class Reply(db.Model):
     __tablename__ = 'Reply'
     id = db.Column(db.Integer, primary_key=True, autoincrement=True)
@@ -337,6 +338,15 @@ def send_index():
     if get_session() == False:
         return Viewrender.gethome(auth=False, tagslist=Tags.query.filter_by().all(), postlist=reversed(Post.query.filter_by().all()[:8]), get_avater=get_avater)
     else:
+        try:
+            serverconf['open_email']
+        except:
+            serverconf['open_email'] = False
+            open('server.conf','w+',encoding='utf-8').write(str(serverconf))
+        if not serverconf['open_email']:
+            get_session('obj').verify_email = True
+            db.session.flush()
+            db.session.commit()
         return Viewrender.gethome(auth=True, userObj=get_session('obj'), tagslist=Tags.query.filter_by().all(), postlist=reversed(Post.query.filter_by().all()[:8]), get_avater=get_avater)
 
 
